/*
Dozen Days of Dice Episode 7: Hearts 
Copyright (c) 2008 Blazing Games Inc.

This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
package com.blazinggames.dozendays.dice.hearts
{
	import flash.display.Sprite;
	import flash.events.Event;
	import flash.events.MouseEvent;
	import flash.text.TextField;
	import flash.text.TextFormat;
	import flash.text.TextFormatAlign;

	import com.blazinggames.dozendays.TextButton;

	public class HeartsGame
	extends Sprite
	{
// ***** VARIABLES **********************************************************

		protected var _manager:HeartsManager;
		protected var _dice:Array;
		protected var _rollButton:TextButton;
		protected var _scoreText:TextField;
		
// ***** CONSTRUCTOR ********************************************************

		public function HeartsGame(manager:HeartsManager)
		{
			_manager = manager;
			_dice = new Array();
			for (var cntr:int = 0; cntr < 6; ++cntr) {
				_dice[cntr] = new HeartsDie();
				_dice[cntr].x = 108 * cntr;
				_dice[cntr].width = 100;
				_dice[cntr].height = 100;
				addChild(_dice[cntr]);
			}
			
			_rollButton = new TextButton("Roll...", 640, 40);
			_rollButton.y = 110;
			addChild(_rollButton);
			_rollButton.addEventListener(MouseEvent.MOUSE_UP, handleRoll);
			
			var format:TextFormat = new TextFormat(null, 15, 0xFFFFFF, null, null, null, null, null, TextFormatAlign.CENTER);
			_scoreText = new TextField();
			_scoreText.y = 160;
			_scoreText.width = 640;
			_scoreText.defaultTextFormat = format;
			addChild(_scoreText);
		}

// ***** Functions - Event Handling *****************************************

		private function handleRoll(evt:Event):void
		{
			for (var cntr:int = 0; cntr < 6; ++cntr) 
				_dice[cntr].quickRoll();

			var score:int = calculateScore();
			if (score >= 0)
				_scoreText.text = "Score for last roll was " + score;
			else
				_scoreText.text = "Last roll wiped out score!";
			_manager.nextPlayer(score);
		}

// ***** Functions - Game Handling ******************************************

		public function calculateScore():int
		{
			var cntr:int;
			var counts:Array = new Array();
			
			// clear out the counts
			for (cntr = 0; cntr < 6; ++cntr) 
				counts[cntr] = 0;
			counts[6] = 0;
			// do the counts
			for (cntr = 0; cntr < 6; ++cntr) 
				++counts[_dice[cntr].getValue()-1];
				
			// analyse counts to determin score;
			if (counts[0] > 2) // three or more ones kills score
				return -1;
			var score:int = 0;
			var indx:int = 0;
			while (counts[indx] > 0) 
				++indx;
			score = 5 * indx;
			
			if (indx == 6) // bonus 5 points for complete sequence
				score += 5;
			return score;
		}
		
		public function setRollState(b:Boolean):void
		{
			_rollButton.visible = b;
		}
	}
}
