/*
Dozen Days of Dice episode 7: Hearts
Copyright (c) 2008 Blazing Games Inc.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
package com.blazinggames.dozendays.dice.hearts
{
	import flash.display.Sprite;
	import flash.events.MouseEvent;

	import com.blazinggames.dozendays.*;

	public class HeartsManager
	extends Sprite
	{
// ***** CONSTANTS **********************************************************

		public static const PLAYER_NAMES:Array = new Array(
			"Red Player", "Yellow Player", "Green Player", 
			"Cyan Player", "Blue Player", "Magenta Player");
		public static const PLAYER_COLORS:Array = new Array(
			0xFF0000, 0xFFFF00, 0x00FF00, 
			0x00FFFF, 0x0000FF, 0xFF00FF);
		public static const PLAYER_BACKGROUNDS:Array = new Array(
			0x500000, 0x505000, 0x005000, 
			0x005050, 0x000050, 0x500050);

// ***** VARIABLES **********************************************************

		protected var _hearts:Hearts;
		protected var _players:Array;
		protected var _game:HeartsGame;
		protected var _toTitle:TextButton;
		protected var _restartGame:TextButton;
		protected var _currentPlayer:int;

// ***** CONSTRUCTOR ********************************************************

		public function HeartsManager(hearts:Hearts)
		{
			_hearts = hearts;
			_players = new Array();
			for (var cntr:int = 0; cntr < 6; ++cntr) {
				_players[cntr] = new HeartsPlayer( this, 
						PLAYER_NAMES[cntr],
						PLAYER_COLORS[cntr],
						PLAYER_BACKGROUNDS[cntr]);
				_players[cntr].y = 200 + 40 * cntr;
				addChild(_players[cntr]);
			}

			_game = new HeartsGame(this);
			addChild(_game);

			_toTitle = new TextButton("return to title...", 310, 40);
			_toTitle.y = 440;
			addChild(_toTitle);
			_toTitle.addEventListener(MouseEvent.MOUSE_UP, handleToTitle);

			_restartGame = new TextButton("Start a new Round", 310, 40);
			_restartGame.x = 330;
			_restartGame.y = 440;
			addChild(_restartGame);
			_restartGame.addEventListener(MouseEvent.MOUSE_UP, handleRestart);
			_restartGame.visible = false;
			resetGame();
		}

//

		public function handleToTitle(evt:MouseEvent):void
		{
			_hearts.changeMode(Hearts.MODE_TITLE);
		}

		public function handleRestart(evt:MouseEvent):void
		{
			resetGame();
		}

		public function resetGame():void
		{
			for (var cntr:int = 0; cntr < 6; ++cntr) {
				_players[cntr].setHighlighting(false);
				_players[cntr].adjustScore(-1);
			}
			_currentPlayer = 5;
			nextPlayer(0);
			_game.setRollState(true);
			_restartGame.visible = false;
		}
		
		public function nextPlayer(score:int):void
		{
			_players[_currentPlayer].setHighlighting(false);
			_players[_currentPlayer].adjustScore(score);
			++_currentPlayer;
			if (_currentPlayer > 5) {
				// see if game over
				var cntr:int;
				var highScore:int = 0;
				for (cntr = 0; cntr < 6; ++cntr)
					if (_players[cntr].getScore() > highScore)
						highScore = _players[cntr].getScore();
				if (highScore >= 100) {
					for (cntr = 0; cntr < 6; ++cntr)
						_players[cntr].setHighlighting(
								_players[cntr].getScore() == highScore);
					_game.setRollState(false);
					_restartGame.visible = true;
					return;
				}
				_currentPlayer = 0;
			}
			_players[_currentPlayer].setHighlighting(true);
		}
	}
}
