/*
Dozen Days of Dice episode 7: Hearts
Copyright (c) 2008 Blazing Games Inc.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
package com.blazinggames.dozendays.dice.hearts
{
	import flash.display.Sprite;
	import flash.text.TextField;
	import flash.text.TextFormat;
	import flash.text.TextFormatAlign;

	public class HeartsPlayer
	extends Sprite
	{
// ***** CONSTANTS **********************************************************

		public static const WIDTH:int = 640;
		public static const HEIGHT:int = 40;

// ***** VARIABLES **********************************************************

		public var _manager:HeartsManager;
		public var _color:uint;
		public var _backColor:uint;
		public var _score:int;

		protected var _nameText:TextField;
		protected var _scoreText:TextField;

		protected var _highlighted:Boolean;

// ***** CONSTRUCTOR ********************************************************

		public function HeartsPlayer(manager:HeartsManager,
				playerName:String = "unknown", 
				colour:uint = 0xFFFFFF,
				backColor:uint = 0x808080)
		{
			_manager = manager;
			_color = colour;
			_backColor = backColor;
			_highlighted = false;
			render();
			
			var nameFormat:TextFormat = new TextFormat(null, 16, colour, null, null, null, null, null, TextFormatAlign.LEFT);
			_nameText = new TextField();
			_nameText.x = 80;
			_nameText.y = 10;
			_nameText.width = WIDTH - 80;
			_nameText.height = 20;
			_nameText.defaultTextFormat = nameFormat;
			_nameText.text = playerName;
			addChild(_nameText);

			var scoreFormat:TextFormat = new TextFormat(null, 32, colour, null, null, null, null, null, TextFormatAlign.RIGHT);
			_scoreText = new TextField();
			_scoreText.x = WIDTH / 2 - 10;
			_scoreText.y = 2;
			_scoreText.width = WIDTH / 2;
			_scoreText.height = 36;
			_scoreText.defaultTextFormat = scoreFormat;
			_scoreText.text = "0";
			addChild(_scoreText);
		}

// ***** Functions - Getting and Setting ************************************

		public function setHighlighting(b:Boolean):void
		{
			_highlighted = b;
			render();
		}

		public function adjustScore(n:int):void
		{
			if (n == -1)
				_score = 0;
			else
				_score += n;
			_scoreText.text = ""+_score;
		}

		public function getScore():int
		{
			return _score;
		}

// ***** Functions - Rendering **********************************************

		private function render():void
		{
			graphics.clear();
			if (_highlighted)
				graphics.lineStyle(3, _color);
			graphics.beginFill(_backColor);
            graphics.drawRect(0, 0, WIDTH, HEIGHT);
            graphics.endFill();
		}
	}
}
